@@ -92,9 +92,9 @@ FORMAT_CURRENCY_EUR_SIMPLE = '[$EUR ]#,##0.00_-'
 
 
 COLORS = r"\[(BLACK|BLUE|CYAN|GREEN|MAGENTA|RED|WHITE|YELLOW)\]"
-LITERAL_GROUP = r'"[^"]+"'
-LOCALE_GROUP = r'\[\$[^\]]+\]'
-STRIP_RE = re.compile("{0}|{1}|{2}".format(COLORS, LITERAL_GROUP, LOCALE_GROUP), re.IGNORECASE + re.UNICODE)
+LITERAL_GROUP = r'".*?"' # anything in quotes
+LOCALE_GROUP = r'\[.+\]' # anything in square brackets, including colours
+STRIP_RE = re.compile(f"{LITERAL_GROUP}|{LOCALE_GROUP}")
 
 
 # Spec 18.8.31 numFmts
@@ -104,8 +104,8 @@ def is_date_format(fmt):
     if fmt is None:
         return False
     fmt = fmt.split(";")[0] # only look at the first format
-    fmt = STRIP_RE.sub("", fmt)
-    return re.search("[dmhysDMHYS]", fmt) is not None
+    fmt = STRIP_RE.sub("", fmt) # ignore some formats
+    return re.search(r"[^\\][dmhysDMHYS]", fmt) is not None
 
 
 def is_datetime(fmt):
