@@ -1,9 +1,13 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
+from copy import copy
 from warnings import warn
 
-from .numbers import BUILTIN_FORMATS, BUILTIN_FORMATS_REVERSE
+from .numbers import (
+    BUILTIN_FORMATS,
+    BUILTIN_FORMATS_MAX_SIZE,
+    BUILTIN_FORMATS_REVERSE,
+)
 from .proxy import StyleProxy
 from .cell_style import StyleArray
 from .named_styles import NamedStyle
@@ -41,7 +45,8 @@ class NumberFormatDescriptor(object):
         if value in BUILTIN_FORMATS_REVERSE:
             idx = BUILTIN_FORMATS_REVERSE[value]
         else:
-            idx = coll.add(value) + 164
+            idx = coll.add(value) + BUILTIN_FORMATS_MAX_SIZE
+
         if not getattr(instance, "_style"):
             instance._style = StyleArray()
         setattr(instance._style, self.key, idx)
@@ -51,10 +56,10 @@ class NumberFormatDescriptor(object):
         if not getattr(instance, "_style"):
             instance._style = StyleArray()
         idx = getattr(instance._style, self.key)
-        if idx < 164:
+        if idx < BUILTIN_FORMATS_MAX_SIZE:
             return BUILTIN_FORMATS.get(idx, "General")
         coll = getattr(instance.parent.parent, self.collection)
-        return coll[idx - 164]
+        return coll[idx - BUILTIN_FORMATS_MAX_SIZE]
 
 
 class NamedStyleDescriptor(object):
@@ -80,7 +85,7 @@ class NamedStyleDescriptor(object):
                 raise ValueError("{0} is not a known style".format(value))
         else:
             style = coll[value]
-        instance._style = style.as_tuple()
+        instance._style = copy(style.as_tuple())
 
 
     def __get__(self, instance, cls):
@@ -91,6 +96,23 @@ class NamedStyleDescriptor(object):
         return coll.names[idx]
 
 
+class StyleArrayDescriptor(object):
+
+    def __init__(self, key):
+        self.key = key
+
+    def __set__(self, instance, value):
+        if instance._style is None:
+            instance._style = StyleArray()
+        setattr(instance._style, self.key, value)
+
+
+    def __get__(self, instance, cls):
+        if instance._style is None:
+            return False
+        return bool(getattr(instance._style, self.key))
+
+
 class StyleableObject(object):
     """
     Base class for styleble objects implementing proxy and lookup functions
@@ -103,6 +125,8 @@ class StyleableObject(object):
     protection = StyleDescriptor('_protections', "protectionId")
     alignment = StyleDescriptor('_alignments', "alignmentId")
     style = NamedStyleDescriptor()
+    quotePrefix = StyleArrayDescriptor('quotePrefix')
+    pivotButton = StyleArrayDescriptor('pivotButton')
 
     __slots__ = ('parent', '_style')
 
@@ -119,22 +143,10 @@ class StyleableObject(object):
             self._style = StyleArray()
         return self.parent.parent._cell_styles.add(self._style)
 
+
     @property
     def has_style(self):
         if self._style is None:
             return False
         return any(self._style)
 
-
-    @property
-    def pivotButton(self):
-        if self._style is None:
-            return False
-        return bool(self._style[6])
-
-
-    @property
-    def quotePrefix(self):
-        if self._style is None:
-            return False
-        return bool(self._style[7])
