@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """Write the workbook global settings to the archive."""
 
@@ -175,8 +175,7 @@ class WorkbookWriter:
 
         rel = Relationship(type="officeDocument", Target=ARC_WORKBOOK)
         rels.append(rel)
-
-        rel = Relationship(Type="%s/metadata/core-properties" % PKG_REL_NS, Target=ARC_CORE)
+        rel = Relationship(Type=f"{PKG_REL_NS}/metadata/core-properties", Target=ARC_CORE)
         rels.append(rel)
 
         rel = Relationship(type="extended-properties", Target=ARC_APP)
