@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """ Read worksheets on-demand
 """
@@ -34,6 +34,7 @@ class ReadOnlyWorksheet(object):
     def __init__(self, parent_workbook, title, worksheet_path, shared_strings):
         self.parent = parent_workbook
         self.title = title
+        self.sheet_state = 'visible'
         self._current_row = None
         self._worksheet_path = worksheet_path
         self._shared_strings = shared_strings
@@ -115,7 +116,9 @@ class ReadOnlyWorksheet(object):
             counter = cell['column']
             if min_col <= counter <= max_col:
                 idx = counter - min_col # position in list of cells returned
-                new_row[idx] = values_only and cell['value'] or ReadOnlyCell(self, **cell)
+                new_row[idx] = cell['value']
+                if not values_only:
+                    new_row[idx] = ReadOnlyCell(self, **cell)
 
         return tuple(new_row)
 
